@@ -35,7 +35,7 @@ for module in rest_settings['modules']:
         conf_mod = import_module(module['path_to_the_config'])
 
         # conf = conf_mod.config
-        conf_mod.config["settings"] = dict_merge(conf_mod.config, common_settings)
+        conf_mod.config["settings"] = dict_merge(common_settings, conf_mod.config)
         conf_mod.config["settings"] = conf_mod.config["settings"]["settings"]
 
         # Load Blueprint
@@ -93,4 +93,5 @@ def discovery_by_type(type):
 
 # Start Flask server
 if __name__ == '__main__':
+    print rest_settings
     app.run(host=rest_settings['host'], port=rest_settings['port'], debug=rest_settings['debug'], threaded=True)
\ No newline at end of file
